package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`%0`!````!",```````!``````````#@!`0``
M`````@```$``.``(`$``%@`5``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````>`````````!X``````````0`````````!````
M!0```````````````````````````````````(R>````````C)X`````````
M``$```````$````&````*/L````````H^P$``````"C[`0``````4`4`````
M``"X%0```````````0```````@````8```!(^P```````$C[`0``````2/L!
M``````#``0```````,`!````````"`````````!0Y71D!`````29````````
M!)D````````$F0```````-P`````````W``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0````H^P```````"C[`0``````*/L!``````#8!```````
M`-@$`````````0`````````O;&EB+VQD+6UU<VPM<&]W97)P8S8T;&4N<V\N
M,0```!$```!,````!`````@````@$!``!4`$@"@`$`2`A@"$@B$```D`!`F(
M@!A!N@0""`````!,````4````%0```!5````6P```%P```!=`````````%\`
M``!@`````````&$```!B````9```````````````:G^:?.K3[P[.WD<M;\7?
M'R[%F[:XC?$.U&34?"'_Y`[9<5@<^J%L8,+E/RRR`8MO0OK7A^)'Q@&[XY)\
M5<,\TF>OS&:(!W#30T75[#-BV^T5C"7,?ZF<F^"G`@IK&IY0H^#[20``````
M```````````````````````````````#``<`N!@`````````````````````
M```#``T`*/L!``````````````````$````28```````````````````````
M`+0!```28`````````````````````````D````1````````````````````
M`````-H!```1`````````````````````````%8!```28```````````````
M`````````!`````28````````````````````````),!```28```````````
M`````````````!@````28````````````````````````.<!```28```````
M`````````````````)\!```28````````````````````````!\````@````
M``````````````````````0#```A`````````````````````````#<````2
M8````````````````````````#T````2`````````````````````````$0`
M```2`````````````````````````-$"```28```````````````````````
M`,("```28````````````````````````&P"```28```````````````````
M`````$L````2``````````````````````````T"```28```````````````
M`````````%(````28````````````````````````*$"```28```````````
M`````````````%D````28````````````````````````&$````2````````
M`````````````````(H"```28````````````````````````&D````28```
M`````````````````````&\````28````````````````````````'@````@
M`````````````````````````+L"```28````````````````````````)0`
M```28````````````````````````)D````28```````````````````````
M`/@!```1`````````````````````````*@"```28```````````````````
M`````#H"```28````````````````````````*`````28```````````````
M`````````"P"```28````````````````````````$H#```28```````````
M``````````````,#```1`````````````````````````%X"```28```````
M`````````````````/`"```28`````````````````````````4#```1````
M`````````````````````*<````28````````````````````````.@"```2
M8````````````````````````&0!```28````````````````````````+``
M```B`````````````````````````+\````@````````````````````````
M`-4````28````````````````````````+,"```28```````````````````
M`````$H"```28````````````````````````-H````28```````````````
M`````````.`````@`````````````````````````)4"```28```````````
M`````````````/H````28````````````````````````(0!```28```````
M`````````````````/\````28````````````````````````'H"```28```
M`````````````````````',!```28`````````````````````````4!```2
M`````````````````````````!8!```28`````````````````````````@"
M```28````````````````````````&H````28```````````````````````
M`!D"```28````````````````````````%,"```28```````````````````
M`````.$"```28````````````````````````!P!```2````````````````
M`````````-D"```28````````````````````````#`!```2````````````
M``````````````,"```28````````````````````````,(!```28```````
M`````````````````#<!```2`````````````````````````#X!```2````
M``````````````````````(#```A`````````````````````````$\!```2
M`````````````````````````/T"```28`@`H"````````!D`@```````-0!
M```28`D`C%L````````0`````````(P#```28`@`K#0````````<!P``````
M`#@$```28`@`L#\```````"8`````````&D#```28`@`D"T````````8````
M`````/8#```28`<`N!@````````0`````````*\#```28`@`R#L```````#H
M`P```````!P$```28`@`J"T````````0`@```````.<#```0`!,`>``"````
M`````````````'H#```28`@`Z#,```````#$`````````)D#```28`@`W"L`
M``````!D`````````*$#```28`@`$#,```````",`````````,4#```28`@`
M9%8```````!``0```````-H#```2``@`N"\````````T`````````#,$```0
M`!,`X!`"`````````````````"\#```28`@`,",```````!<`````````/P#
M```28`@`["\```````!D`0```````-`#```1`!(`<``"```````(````````
M`!4$```0`!(`>``"`````````````````.P#```2``@`!",`````````````
M`````/,#```28`@`T%4```````"4`````````#@#```28`@`G#,```````!,
M`````````%,#```28`@`N"P```````#8`````````"D$```28`@`I%<`````
M``"D`0````````@$```28`@`4#$```````#``0````````!O<&5N9&ER`'-T
M9&5R<@!R96%L;&]C`&%C8V5S<P!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L
M<V5E:P!G971P:60`<W1R8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N
M8VUP`&QS=&%T`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!O<&5N`'-T<G-T<@!S=')C:'(`<F5A9&QI;FL`7U]C>&%?9FEN86QI>F4`
M7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E
M<E1-0VQO;F5486)L90!R96%D`')M9&ER`%]?97)R;F]?;&]C871I;VX`;6MD
M:7(`<'1H<F5A9%]G971S<&5C:69I8P!M96UC<'D`<W1R;&5N`%]?<W1A8VM?
M8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`
M4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!0
M97)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V
M7V9L86=S`%]F:6YI`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,
M7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!0
M97)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A
M;&QO8P!F<')I;G1F`'-T<F1U<`!P=&AR96%D7V%T9F]R:P!R96%D9&ER`'-P
M<FEN=&8`<W1R=&]K`'-T<FYC<'D`7U]L:6)C7W-T87)T7VUA:6X`7U]?96YV
M:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"UP<&,V-&QE+G-O+C$`7W-T87)T
M7V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-U<G)E;G1?97AE
M8U]P<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R
M7VUK=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?
M4$%27T)/3U0`<VAA7W5P9&%T90!M>5]P87)?<&P`<&%R7V)A<V5N86UE`%]?
M8G-S7W-T87)T`'-H85]I;FET`'!A<E]D:7)N86UE`'!A<E]I;FET7V5N=@!?
M961A=&$`<&%R7V9I;F1P<F]G`'-H85]F:6YA;`!?96YD`'!A<E]C;&5A;G5P
M`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%`````````````@``````
M%@````````````(``````!```@``````%@````````"X6P```````!@``@``
M````%@````````#C6P```````"@``@``````%@````````"]6P```````#``
M`@``````%@````````"]7````````#@``@``````%@````````#(6P``````
M`$```@``````%@````````#/7````````$@``@``````%@````````#06P``
M`````%@``@``````%@````````#46P```````&```@``````%@````````#9
M6P```````'```@``````%@````````!Q7@````````C_`0``````)@```!X`
M`````````````!#_`0``````)@```#4``````````````!C_`0``````)@``
M`"\``````````````"#_`0``````)@````T``````````````"C_`0``````
M)@```#```````````````##_`0``````)@```"L``````````````#C_`0``
M````)@```"(``````````````$#_`0``````)@```#H``````````````$C_
M`0``````)@````4``````````````%#_`0``````)@```$``````````````
M`%C_`0``````)@```#L``````````````&#_`0``````)@````8`````````
M`````!C]`0``````%0````,``````````````"#]`0``````%0````0`````
M`````````"C]`0``````%0````<``````````````##]`0``````%0````@`
M`````````````#C]`0``````%0````D``````````````$#]`0``````%0``
M``H``````````````$C]`0``````%0````L``````````````%#]`0``````
M%0````P``````````````%C]`0``````%0````T``````````````&#]`0``
M````%0````\``````````````&C]`0``````%0```!```````````````'#]
M`0``````%0```!$``````````````'C]`0``````%0```!(`````````````
M`(#]`0``````%0```!,``````````````(C]`0``````%0```!0`````````
M`````)#]`0``````%0```!4``````````````)C]`0``````%0```!8`````
M`````````*#]`0``````%0```!<``````````````*C]`0``````%0```!@`
M`````````````+#]`0``````%0```!D``````````````+C]`0``````%0``
M`!H``````````````,#]`0``````%0```!L``````````````,C]`0``````
M%0```!P``````````````-#]`0``````%0```!T``````````````-C]`0``
M````%0```!\``````````````.#]`0``````%0```"```````````````.C]
M`0``````%0```"$``````````````/#]`0``````%0```",`````````````
M`/C]`0``````%0```"0```````````````#^`0``````%0```"4`````````
M``````C^`0``````%0```"8``````````````!#^`0``````%0```"<`````
M`````````!C^`0``````%0```"D``````````````"#^`0``````%0```"H`
M`````````````"C^`0``````%0```"P``````````````##^`0``````%0``
M`"T``````````````#C^`0``````%0```"X``````````````$#^`0``````
M%0```"\``````````````$C^`0``````%0```#```````````````%#^`0``
M````%0```#$``````````````%C^`0``````%0```#(``````````````&#^
M`0``````%0```#,``````````````&C^`0``````%0```#0`````````````
M`'#^`0``````%0```#8``````````````'C^`0``````%0```#<`````````
M`````(#^`0``````%0```#@``````````````(C^`0``````%0```#D`````
M`````````)#^`0``````%0```#P``````````````)C^`0``````%0```#T`
M`````````````*#^`0``````%0```#X``````````````*C^`0``````%0``
M`#\``````````````+#^`0``````%0```$$``````````````+C^`0``````
M%0```$(``````````````,#^`0``````%0```$,``````````````,C^`0``
M````%0```$0``````````````-#^`0``````%0```$4``````````````-C^
M`0``````%0```$8``````````````.#^`0``````%0```$<`````````````
M`.C^`0``````%0```$@``````````````/#^`0``````%0```$D`````````
M`````/C^`0``````%0```$L```````````````(`3#Q(9D(XI@((?!```?CA
M_R'XK0P`2````&"50`!(````8"``(3@0``'HI@,(?"``@$X`````````````
M`````````````!@`0?C__X(]&'Z,Z:8#B7T@!(!.````````````````&`!!
M^/__@CTX?HSII@.)?2`$@$X````````````````8`$'X__^"/4A_C.FF`XE]
M(`2`3@```````````````!@`0?C__X(]\'Z,Z:8#B7T@!(!.````````````
M````&`!!^/__@CUH?HSII@.)?2`$@$X````````````````8`$'X__^"/:!^
MC.FF`XE](`2`3@```````````````!@`0?C__X(]J'^,Z:8#B7T@!(!.````
M````````````&`!!^/__@CV`?HSII@.)?2`$@$X````````````````8`$'X
M__^"/3!^C.FF`XE](`2`3@```````````````!@`0?C__X(]`'^,Z:8#B7T@
M!(!.````````````````&`!!^/__@CUP?XSII@.)?2`$@$X`````````````
M```8`$'X__^"/=A_C.FF`XE](`2`3@```````````````!@`0?C__X(]B'^,
MZ:8#B7T@!(!.````````````````&`!!^/__@CT@?HSII@.)?2`$@$X`````
M```````````8`$'X__^"/5A^C.FF`XE](`2`3@```````````````!@`0?C_
M_X(]F'^,Z:8#B7T@!(!.````````````````&`!!^/__@CW`?XSII@.)?2`$
M@$X````````````````8`$'X__^"/?!_C.FF`XE](`2`3@``````````````
M`!@`0?C__X(]<'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CU(?HSI
MI@.)?2`$@$X````````````````8`$'X__^"/<A_C.FF`XE](`2`3@``````
M`````````!@`0?C__X(]0'^,Z:8#B7T@!(!.````````````````&`!!^/__
M@CT8?XSII@.)?2`$@$X````````````````8`$'X__^"/0A_C.FF`XE](`2`
M3@```````````````!@`0?C__X(]*'Z,Z:8#B7T@!(!.````````````````
M&`!!^/__@CU0?HSII@.)?2`$@$X````````````````8`$'X__^"/9A^C.FF
M`XE](`2`3@```````````````!@`0?C__X(]>'Z,Z:8#B7T@!(!.````````
M````````&`!!^/__@CTX?XSII@.)?2`$@$X````````````````8`$'X__^"
M/>!_C.FF`XE](`2`3@```````````````!@`0?C__X(]H'^,Z:8#B7T@!(!.
M````````````````&`!!^/__@CVX?HSII@.)?2`$@$X````````````````8
M`$'X__^"/2!_C.FF`XE](`2`3@```````````````!@`0?C__X(]L'^,Z:8#
MB7T@!(!.````````````````&`!!^/__@CWX?HSII@.)?2`$@$X`````````
M```````8`$'X__^"/<!^C.FF`XE](`2`3@```````````````!@`0?C__X(]
M6'^,Z:8#B7T@!(!.````````````````&`!!^/__@CV0?HSII@.)?2`$@$X`
M```````````````8`$'X__^"/6A_C.FF`XE](`2`3@```````````````!@`
M0?C__X(]8'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CWX?XSII@.)
M?2`$@$X````````````````8`$'X__^"/>A^C.FF`XE](`2`3@``````````
M`````!@`0?C__X(]@'^,Z:8#B7T@!(!.````````````````&`!!^/__@CVP
M?HSII@.)?2`$@$X````````````````8`$'X__^"/8A^C.FF`XE](`2`3@``
M`````````````!@`0?C__X(],'^,Z:8#B7T@!(!.````````````````&`!!
M^/__@CW0?HSII@.)?2`$@$X````````````````8`$'X__^"/7A_C.FF`XE]
M(`2`3@```````````````!@`0?C__X(]*'^,Z:8#B7T@!(!.````````````
M````&`!!^/__@CWH?XSII@.)?2`$@$X````````````````8`$'X__^"/6!_
MC.FF`XE](`2`3@```````````````!@`0?C__X(]V'Z,Z:8#B7T@!(!.````
M````````````&`!!^/__@CU0?XSII@.)?2`$@$X````````````````8`$'X
M__^"/1!_C.FF`XE](`2`3@```````````````!@`0?C__X(]X'Z,Z:8#B7T@
M!(!.````````````````&`!!^/__@CVX?XSII@.)?2`$@$X`````````````
M```8`$'X__^"/:A^C.FF`XE](`2`3@```````````````!@`0?C__X(]R'Z,
MZ:8#B7T@!(!.````````````````&`!!^/__@CV0?XSII@.)?2`$@$X`````
M```````````8`$'X__^"/=!_C.FF`XE](`2`3@```````````````!@`0?C_
M_X(]0'Z,Z:8#B7T@!(!.`````````````````@!,/&!>0CBF`@A\\/_!^_C_
MX?L0``'X<?\A^'``@?AH`*'X<`"!.&@`H3A\`&&0?`!A.*W[_TL8`$'H````
M8%"`HN@```!@6(!BZ'@KI'SQ^/]+&`!!Z````&!@@"+I````8#B`XNL``,F+
M```>+$``@D!-^/]+&`!!Z````&```",LV)%B^!``@D`!`&`X4?[_2Q@`0>@)
M_?]+&`!!Z```?X"]^?]+&`!!Z+D+PYL``'^`K?G_2Q@`0>@*!B.)`@`I80H&
M(YD``'^`E?G_2Q@`0>@*!B.)`0`I80H&(YE\`&&`!0!C.+0'8WPD'V-XL?C_
M2Q@`0>A^`*'H<`#AZ````&````!@````.<B18OAX&V9\```GZ0``!2P``"/Y
M_O\B/6O?*3D(`"/Y````8'"!(ND0`"/Y_O\B/6[?*3D8`"/Y!``@.<"1(I'_
M_R4Y(``I>0$`*3D(`(%!`0`@.0$`*2P!``@Y__\I.=``@D`#`*4X``!`.0``
M`&#8D6+HM`>E?/[_@CPD'ZEX``#@.$"MA#@J249]*?O_2Q@`0>AY&W]\&`""
M0````&#8D6+H\?S_2Q@`0>AX&W]\````8-B18NA=^?]+&`!!Z/[_8CQWW6,X
M*00`2```(RP\`()`````8-"1(ND``"DL&`""0/[_8CPLW6,X!00`2````&#0
MD6+X````8-"18N@``",L"`""004=`$@```!@V)%BZ*'W_TL8`$'H.?G_2Q@`
M0>B0`"$X>/OC?V@W`$@D'PIY*E"'?`,`2#FT!TI])!]*>2I1AGP,__]+````
M``````&``@```@!,//Q;0C@H`(R`%&*$?'@+(WSD!B%X````..'_`?BF`PA\
M$0``2$38`0`"`$P\T%M".*8""'P(`*,X_O_B/(S<YSC^_\(\N)G&.````#D0
M``'XX?\A^`(`@^C^_V(\H*%C.)GY_TL8`$'H(``A.!```>BF`PA\(`"`3@``
M```````!@````````&`"`$P\<%M".````&````!@>(%B.'B!(CD`&"E\(`""
M30```&`(@(+I```L+"``@DVF`@A\I@.)?1```?CA_R'X&`!!^"$$@$X8`$'H
M(``A.!```>BF`PA\(`"`3@``0F`"`$P\$%M".````&````!@>(%B.'B!@CA0
M((-\=!Z$?'0.A'R5`81\(`""30```&`0@(+I```L+"``@DVF`@A\I@.)?1``
M`?CA_R'X&`!!^"$$@$X8`$'H(``A.!```>BF`PA\(`"`3@```&```$)@`@!,
M/*!:0C@```!@>($BB0``"2P@`(),I@((?````&`8@"+IZ/^A^_#_P?L``"DL
M$``!^,'_(?@8`$'X%`""00```&``@6+H^?;_2Q@`0>C__T(]___"/P```&"`
M@2+I0'Q*.3A\WCM04-Y___^B/W0>WG\X?+T[___>.T#P*7P\`(!`.`#A^P``
M`&"`@>([`0`I.20?*GD``#_Y*E"=?:8#B7TA!(!.&`!!Z```/^E`\"E\W/^`
M03@`X>M]_O]+````8""`(ND``"DL%`""0?[_8CP,&V,XB?7_2Q@`0>A``"$X
M`0`@.0```&`0``'HZ/^AZ_#_P>MX@2*9I@,(?"``@$X```!@````8```0F`"
M`$P\D%E".````&`H@"+I```I+#P`@D&F`@A\````8/[_8CR(@8(X#!MC.!``
M`?CA_R'XG?/_2Q@`0>@@`"$X$``!Z*8#"'Q`_O]+``!"8#C^_TL"`$P\/%E"
M.*8""'P5-`!(>1M\?+'_(?@``,`[)`""00```&`P@"+I``#`.W@CFGQXXX5_
M``"IZP``/2P<`()`4``A.'CSPW\0-`!(/0`)*!0`@D$!`*4X```EB0``*2SL
M_X)`4"B\?'CKNW^T![]\``#;ZP``/BS(_X)!>/OE?WCCA']X\\-_E?;_2Q@`
M0>@``",L*`""0*[X/GT]``DL'`""0%#8O7\!`/\[=!Z]?Q3ZWG\``+J3B/__
M2P@`>SNP__]+``````````&`!@```@!,/&Q80CBF`@A\$``!^)'_(?AD`($X
M\(\MZ6@`(?D``"`Y%?__2V@`(>GPCTWI>5(I?0``0#D,`()!4?3_2Q@`0>AP
M`"$X$``!Z*8#"'P@`(!.``````````&``````@!,/`Q80CBF`@A\\/_!^_C_
MX?MX&W]\$``!^('_(?CPCRWI:``A^0``(#ED`,$[>//$?WC[XW^A_O]+```C
M+"``@D!H`"'I\(]-Z7E2*7T``$`Y/`""0=7S_TL8`$'H9@`AZ20?*7GX_TDY
M````8#"`(ND``"GI%%(I?1``2>D``"HL"0!)^?3_@D"D__]+@``A.+@R`$@`
M`````````8`"```"`$P\:%=".*8""'PY,@!(P?XA^'D;?GSPCRWI^``A^0``
M(#EH`()!```^B0``"2Q<`()!-?'_2Q@`0>AY&WQ\3`""0?[_8C_^_T(__O\B
M/^/<>SOBW%H[Y=PY.V@``3MXXX-_9?3_2Q@`0>AY&W]\.`""0'CC@W^Q]O]+
M&`!!Z'CSPW]E\O]+&`!!Z/@`(>GPCTWI>5(I?0``0#G4`()!Z?+_2Q@`0>@3
M`/\[>-MD?WC[XW_U\O]+&`!!Z```(RR@_X)!>--$?WC[XW_=\O]+&`!!Z```
M(RR(_X)!>//#?ZGV_TL8`$'H>!M]?'C[XW^9]O]+&`!!Z!0:?7P"`&,XM`=C
M?&7W_TL8`$'H>/OF?WCSQ7]XRR1_>!M]?,WR_TL8`$'H>,,$?WCKHW_]\/]+
M&`!!Z/__`RQXZZ-_*`""08``(8$F!"E5`$`)+!@`@D"Y_O]+>.NC?]'S_TL8
M`$'H`/__2Z7P_TL8`$'HZ/__2T`!(3@(,0!(``````````&`"````@!,/.15
M0CBF`@A\^/_A^W@;?WP0``'X,?\A^"@`@3CPCRWIN``A^0``(#G9]O]+&`!!
MZ```(RQ4`()`0``A@28$*54`0`DH$`""0?__*FT`H`HL'`""0`(`@#AX^^-_
M!??_2Q@`0>@T`&-\?MEC5+@`(>GPCTWI>5(I?0``0#D4`()!@?'_2Q@`0>@`
M`&`XX/__2]``(3B0,`!(``````````&``0```@!,/#Q50CBF`@A\$3``2%'_
M(?AX&W]\>".>?/"/+>EH`"'Y```@.0``)(D]``DL"`""0`$`Q#MX\\-_(?7_
M2Q@`0>AD`($X>!M]?'C[XW^Y^_]+>1M\?$@`@D$!]?]+&`!!Z$`8/7RT`(%!
M```@.:Y(7GT``"HLKDE<?0$`*3GP_X)`:``AZ?"/3>EY4BE]``!`.7`!@D'%
M\/]+&`!!Z````&`P@&+K```@.0``.^OX_QDYM`<\?0$`*3DD'RIY*E!(?0``
M*BSL_X)`````8+B!(H$"`)PXM`>$?"0?A'@```DLX`""07C+(W]1[_]+&`!!
MZ```(RP``'OXB/^"00$`/#D``%OI````.;0'*7TD'REY*DD*?60`@9-X^^E_
M``!)B0``*BP,`()!/0`**,P`@D!F`('K````8#"`8NM02#]]`@!].+0'*7T4
M2F-\``!;Z^GT_TL8`$'H)!^<>P``(RPJX7I\'/^"068`(>D``%OI____.R0?
M*7DJ2"I]`0!?C7A+*'T!`"DY```J+/__29D,`()!/0`**.3_@D`]`$`Y``!(
MF0``0#FN4!Y]```H+*Y1"7T!`$HY\/^"0,3^_TL!`"`Y````8'@C@WRX@2*1
M:?3_2Q@`0>AY&WI\I/Z"020?A7MXRR1_L?+_2Q@`0>@``%O["/__2P$`*3D@
M__]+L``A.$PN`$@``````````8`'```"`$P\)%-".*8""'P```!@.(`BZ1``
M`?CA_R'X``!I@`7O_TL8`$'H````8$"`HNC^_\(\_O^"/-@9QCCKW(0X!?'_
M2Q@`0>@@`"$X$``!Z*8#"'P@`(!.``````````&``````@!,/,!20CBF`@A\
M^/_A^P```&`X@.+K$``!^-'_(?@``'^`G>[_2Q@`0>AY__]+``!_@(WN_TL8
M`$'H_O_B//[_HCQJW^<X_O^"/````#EX.^9\R+RE.`?=A#C%[O]+&`!!Z#``
M(3B<+0!(``````````&``0```@!,/$A20CBF`@A\+2T`2&'?(?CPCRWI>"`A
M^0``(#FI[/]+&`!!Z&@`X3O^_\(\_O^"/'@;97P<W<8X(-V$.'C[XW]P$*$[
M@>[_2Q@`0>AX^^-_`!"@.'CKI'\``.`[Z?'_2Q@`0>@```,L.`"`0;0'?GP!
M`'XXM`=C?,WR_TL8`$'H>1M_?!P`@D%X\\5_>.ND?Q7S_TL8`$'H```@.:[Q
M/WUX("'I\(]-Z7E2*7T``$`Y#`""0;'M_TL8`$'HH"`A.'C[XW^H+`!(````
M``````&``P```@!,/'!10C@H__]+`````````````````@!,/%A10CBF`@A\
M)H"0?0@`@9$1+`!(H>XA^'@;?GS^_V(\+-UC.'@CGWSPCRWI^!`A^0``(#F]
M^/]++P"`.'@;>WQX\\-_,>S_2Q@`0>@``",L,`""0?[_8CQX\\1_-=UC.,'[
M_TOX$"'I\(]-Z7E2*7T``$`Y>`&"0?WL_TL8`$'H>//#?_[_0C_M\/]+&`!!
MZ$+=6CO^_R(_>--$?_[_XCZT!WU\>/OC?XWQ_TL8`$'H_O_"/@``@#H``#LN
MX]PY.W@;?WP````[`0"].T3=]SH5WM8Z^`"!.V@`H3H`@)1B```_+'#_@D$`
M`#^)```)+`@`@D!XRS]_(`"207C[Y']XVV-_D>S_2Q@`0>AXTT1_```C+,@`
M@D%X^^-_6?#_2Q@`0>BT!VE\__]).;0'2GVN4!]]+P`(+)``@D$42CU]_P\)
M+!#_@4%X\\=_>+OF?GC[Y7]XL\1^>..#?WGL_TL8`$'H>*ND?GCC@W^IZO]+
M&`!!Z```(RQ<`()`@``A@28$*54`H`E\3`""0`$`@#AXXX-_0?'_2Q@`0>@`
M`",L-`""0/[_8CQXXX1_-=UC.''Z_TMXXX-__>__2Q@`0>AX&WY\H/[_2ZY1
M'W]X4TE]6/__2WC31'\``&`X6?#_2Q@`0>AX&W]\^/[_2V`1(3AX\\-_"`"!
M@2"!D'U<*@!(``````````.`#```>!MI?'A+(WT0``!(+P`**`$`*3GP_X)!
M``!)B0``*BSL_X)`(`"`3@````````````````(`3#P43T(XI@((?/C_X?MY
M&W]\$``!^-'_(?@0`()!```_B0``"2P0`()`_O]B/./<8S@4`0!(_>[_2Q@`
M0>C__R,Y%$J_?'@;:7P4&G]\__]C.$`8/WP,`(%!__\_+`@`@D`!`"`Y`0`I
M+/__*3F\`()!``!%B2\`"BR@`()!0"@_?%`H/WT!`"DY"`"!0`$`(#D!`"DL
M__\I.9``@D$``$6)__\%.2\`"BQX`()`__]%.5`H/WU`4#]\#`"!0?__/RP(
M`()``0`@.0$`*2S__Z4X__\I.1``@D$``$6)+P`*+.C_@D%0*+]\``!@.`(`
M)3D`$"DH6`"!00```&`!`*4XP($B.7C[Y']X2R-]I>W_2Q@`0>@X``!(__^E
M.$C__TMX0P5];/__2T`H/WR`_X)````_B?[_8CQ$W6,X+P`)+.C^@D$M[O]+
M&`!!Z#``(3@$*0!(``````````&``0```@!,/+!-0CBF`@A\_O]B/$;=8SB)
M*`!(4?\A^/[_PC_^_Z(_9]W>.RS=O3O^_^(__O^"/X/=_SN-W9P[\(\MZ8@`
M(?D``"`Y_O\B/>(9*3D``,GH"`#IZ!``">D8`$GI(``IH6``P?AH`.'X<``!
M^7@`0?F``"&Q-?7_2_[_8CQ/W6,X*?7_2_[_8CQ7W6,X'?7_2_[_8CQ@W6,X
M$?7_2WCSPW\)]?]+_O]B/'?=8SC]]/]+>.NC?_7T_TMX^^-_[?3_2WCC@W_E
M]/]+_O]B/)?=8SC9]/]+_O]B/#7=8SC-]/]+_O]B/*'=8SAA]/]+>1MD?`P`
M@D%XXX-_@??_2_[_8CRRW6,X1?3_2WD;9'P0`()!_O]B/+W<8SAA]_]+_O]B
M/,3=8S@E]/]+>1MD?#@`@D%XZZ-_1??_2_[_@CQX\\-_\-V$.#7W_TN(`"'I
M\(]-Z7E2*7T``$`Y4`""07'H_TL8`$'H_O]B/-3=8SC=\_]+>1MD?`P`@D%X
M^^-_N/__2_[_@CP*`*`XY=V$.'$`83C]Z?]+&`!!Z```(RR<_X)`>P"!.-3_
M_TNP`"$X)"<`2``````````!@`0```(`3#SP2T(X````8`B!(H'__PDL8`""
M0*8""'S^_V(\@]UC.!```?BA_R'X8?/_2P``0#D``",L'`""00``(XD``"DL
M$`""03``*6G__TDQ$$E*?0```&!@`"$X"(%"D1```>@```!@I@,(?`J!8N@@
M`(!.````8`J!8N@@`(!.``````````&``````@!,/&1+0CBF`@A\$``!^.'_
M(?A1ZO]+&`!!Z.GK_TL8`$'H```C+`@`@D$``&/H(``A.!```>BF`PA\(`"`
M3@`````````!@`````(`3#P82T(XI@((?/DE`$B!_R'X_O^"/W@;?WSRW9P[
M>..#?Y'R_TMX^^1_>1M^?!``@D$``#Z)```)+!0`@D!XXX-_H?7_2X``(3CP
M)0!(Z>G_2Q@`0>@``",L[/^"0'C[XW_5ZO]+&`!!Z'@;?7QX\\-_Q>K_2Q@`
M0>@4&GU\`@!C.)7K_TL8`$'H_O_"//[_@CP5WH0X>//'?W@;?7Q"W<8X>/OE
M?_'F_TL8`$'H>.ND?XS__TL``````````8`$```"`$P\5$I".*8""'P``"`Y
MF($I81DE`$C__P`\_O]"/Q!^`&`LW5H[>!M[?'C30W]J`2%\%`HI?:"!X3OP
MCTWI``!)^0``0#D```!@$($BZ<!^/_D```!@&($BZ<A^/_D```!@(($BZ=!^
M/_D```!@*($BZ?!^/_D```!@,($BZ?A^/_D```!@.($BZ0!_/_D```!@0($B
MZ0A_/_D```!@2($BZ1!_/_D```!@4($BZ1A_/_D```!@6($BZ=A^/_D```!@
M8($BZ>!^/_D```!@:($BZ>A^/_D9\?]+>1M^?$P`@D$``#Z)```)+$``@D%5
M_O]+>//#?[WI_TL8`$'H>!M^?```(#F8@2EA%`HI?0``2>GPCRWI>4I*?0``
M(#GD!8)!4>7_2Q@`0>C-_?]+T'Z_.WD;?GR0`8)!>//#?_[_@C\QZ?]+&`!!
MZ/__WCL)WIP[I`]C>`$`8SCYZ?]+&`!!Z'@;>7QX&WU\`0"^C```)2QL`8)`
MZ'Z_.PD`W>L``#XL/`""07CSPW]E\/]+>1M^?.C_@D$``#Z)```)+-S_@D'5
M\O]+```C+-#_@D%X\\-_`>G_2Q@`0>AX&WY\N'Z?.P``/BP<`()`"0"\ZP``
M/2Q(`8)!```]B0``"2P8`8)`>//#?_[_XCZ)Z/]+&`!!Z$3=]SIX&WQ\>,LC
M?W7H_TL8`$'H%!J<?P0$G#NT!YQ_>..#?SWI_TL8`$'H_O_B//[_@CQXRRA_
M#M[G.'B[YGYX\\5_$]Z$.'@;?7R5Y/]+&`!!Z,`!@#AXZZ-_Y>/_2Q@`0>C_
M_P,LR`""0#7I_TL8`$'H`@#CZ!$`!RRT`()!````8$B`(ND``+OH_O^"/'CK
MIG\<WH0X``!IZ$7F_TL8`$'H``#`.VC^_TM1[_]+>1MI?"``@D$``"F)```)
M+!0`@D']Y_]+&`!!Z'D;?GQX_H)`"0!]Z```(RS0_X)`_O_"/P+>WCM@_O]+
M>.NC?WCCA'_MX_]+&`!!Z`(`O3MX_O]+>.NC?WWQ_TL``",LR/Z"07CKHW^I
MY_]+&`!!Z'@;?GRL_O]+``#`.\3^_TL@?Y\X>.NC?TGH_TL8`$'H>1MX?"P`
M@D$```!@2(`BZ0``N^C^_X(\>.NF?U?>A#@``&GH?>7_2Q@`0>@X__]+.'\_
M@28$*54`0`DLS/^"0#Q_WX/=Y?]+&`!!Z``8/GRX_X)`.'\_@?X%*57``0DL
MJ/^"0'CC@W^YY_]+&`!!Z'@;?GS^_V(\_=UC.$'N_TL``",LJ`&"0```.^MX
MRR-_L>;_2Q@`0>@#``,LM`=\?(0`@4#\_WPX_O^"/*K>A#@4&GE\K>+_2Q@`
M0>@``",L9`""0`0`'"P8`()!^_^<.[0'G'^NX#E]+P`)+$@`@D`(`)OK```\
M+#P`@D%XXX-_4>;_2Q@`0>@#`",H*`"!0/S_8SC^_X(\K]Z$.!0:?'Q1XO]+
M&`!!Z```(RP(`()`>..9?Q7Z_TL``",L\`&"0```@#AXRR-_J>;_2Q@`0>AY
M&WQ\V`&"00(`H#CN_X`XL>3_2Q@`0>CX?W\[!@"@.'C;9']XXX-_F>7_2Q@`
M0>CX?S^)```)+-@`@D#Y?S^)0P`)+,P`@D#Z?S^)00`)+,``@D#[?S^)0P`)
M++0`@D#\?S^)2``)+*@`@D#]?S^)10`)+)P`@D`"`*`XQO^`.'CC@W\]Y/]+
M&`!!Z"D`H#AXVV1_>..#?RGE_TL8`$'H_O\"/7C;9W]JWP@Y_O^"/'B[YGYX
MZZ5_M-Z$.'CSPW^AX?]+&`!!Z'CKHW_5XO]+&`!!Z'C30W]X\\1_T>__2WCS
MPW_M^?]+J/O_2P``F^M1Y?]+&`!!Z'@;9'QXXX-_D?/_2WD;>7Q$_H)`//[_
M2P``H#@``(`X>..#?___`#NAX_]+&`!!Z/A_/SL@!!A7B1L`2````&!X&WM\
M>,,%?WC+)']XXX-_>>3_2Q@`0>@```,LM`=E?'``@4%XXX-_L'^?.SWC_TL8
M`$'H>-MD?WCC@W_^_P(_R'\_.Q$=`$@```!@``!@.PG>&#NNV+Q\>,LC?WC#
M!'\!`'L[`@`Y.\'@_TL8`$'H%``[*.#_@D```"`Y_O\"/6K?"#G(?_\X\'\_
MF>C^_TMXRR1_>-MC?WT;`$@```!@9/__2_[_@CS^_V(\\-V$.(/=8SC![O]+
M_O_B/_[_@C]JW_\[T=Z<.V'>_TL8`$'H_O^"/'C[Z']XN^9^>.NE?W@;9WS#
MWH0X>//#?SW@_TL8`$'HP`&`.'CSPW^-W_]+&`!!Z/__`RR(_H)`W>3_2Q@`
M0>@``".!$0`)+'3^@D`)WO]+&`!!Z`$`&#MX^^E_M`<8?WB[YGYX&V=\>,,(
M?WCKI7]XXX1_>//#?]W?_TL8`$'HH/__2P``(>AX\\-_6!X`2``````````!
M@`D```(`3#PX0T(XI@((?`D>`$AA_R'X````8#B`XNL``'^`&=__2Q@`0>AX
M&WY\``!_@`G?_TL8`$'HN``^B;D`(YG^_V(\9]UC.(WJ_TL``",L'`""00``
M(XDQ``DL$`""0`$`(XD```DL"`""027U_TL``'^`````8+B!HCN]WO]+&`!!
MZ/[_@CP+`,`X`0"@..+>A#CEX/]+&`!!Z```(RR4`()```!_@)'>_TL8`$'H
M_O^"/`,`P#@!`*`XY]Z$.+G@_TL8`$'H>1M^?'`!@D```'^`9=[_2Q@`0>C^
M_X(\`P#`.`$`H#@'WX0XC>#_2Q@`0>AY&WY\U`&"0?[_8CPUW6,XT>G_2WD;
M?'R(`8)!``!_@"7>_TL8`$'H$``^Z7CCA7\``(GH\=[_2Q@`0>B<`0!($``C
MZ2``(#\!`,`[``0Y8R@`2>L($#V!__]^.P``?X"T!WM_`/`)?"@`@4#9W?]+
M&`!!Z```P#AXVV5_>--$?T7A_TL8`$'H>1M\?"``@D````!@P)$B@?__*3D`
MV`E\$/^"0`$`P#N,``!($!!=Z20?R7LJ2`I_``!<Z0P`*H$X2"E_``0)+"@`
M@D`0`(KH>,,#?['=_TL8`$'H```C++#_@D`!`-X[M`?>?VC__TL``'^`4=W_
M2Q@`0>@``)SH`@#`.```H#C=WO]+&`!!Z'@;9'R\__]++=W_2Q@`0>AXTT1_
M`0#>.[0'WG^YW/]+&`!!Z`@0/8$``'^``/`)?-C_@4%L_O]+``!_@/G<_TL8
M`$'H$``^Z?[_HCSIWJ4X``")Z,'=_TL8`$'H$``^Z0``*>D,`"F!0``I=6#^
M@D$``'^`P=S_2Q@`0>@0`#[I``")Z/'=_TL8`$'H0/[_2V7N_TMY&WQ\``!_
M@-``@D&5W/]+&`!!Z!``/NEXXX5_``")Z&'=_TL8`$'H>..#?S7>_TL8`$'H
M``!_@&G<_TL8`$'H>!M^?```?X!9W/]+&`!!Z/[_@CP!`*`X[MZ$.&7:_TL8
M`$'H_O^B/`/?I3AX&V1\>//#?PW=_TL8`$'H``!_@"'<_TL8`$'H```@.;D`
M(YG^_V(\+-UC.*7G_TL```!@```C+-"18OA,`()`````8,B18NBA]?]+````
M8```(RS0D6+X,`""0/[_8CP)WV,X\=S_2Q@`0>C)V_]+&`!!Z````&#(D4+I
M$``^Z0``JNB<_?]+````8-"18NC``8`X@=O_2Q@`0>@1``,L>!MF?"P`@D$!
M`",Y`0`)*"``@4`0$#WI&!"]Z/[_8CPJWV,X``")Z(W<_TL8`$'HH``A.'0:
M`$@``````````8`(```"`$P\4#]".*8""'SP_\'[^/_A^W@;?WP0``'XD?\A
M^"7P_TOE[_]+>!M^?#WS_TL``",L4`""00``/RQ(`()!```_B0``"2P\`()!
M_O^"/'CSPW\.WH0X&=[_2Q@`0>@`&#Y\(`""0'``(3AX^^-_$``!Z/#_P>OX
M_^'KI@,(?'#G_TMP`"$X"!H`2``````````!@`(```(`3#RX/D(XI@((?#@`
MPSB%&0!($?TA^/"/+>FH`B'Y```@.0@`(#FF`RE]*``!.0``1NDL-"!]$``(
M.0@`QCCP_RCY(,))>2(`1WDN!"E5($9*>7A3*7THP.IX>%,I?1Y"YU1X.RE]
M^/\H^<3_`$)``"`Y(``!.:8#*7UP`"CI2`#HZ!@`2.EX.BE]>%(I?0D`2.EX
M4BE]I`\J><(/*7EX2TE](``I>8``*/G0_P!"```#Z"``8^D(`(/H$`##Z!@`
MH^C"+@EXI"X'>'A+YWPH`"'I9/"*>"``YWAX*LA\."`(?63P'WB"6BD]>"H(
M?9EY*3D46BE]%$KG?(+PB7AX2TI],``AZ11"YWP@`%QY(`#^>'CBR'R"6BD]
M.``(?9EY*3EX,@A]%"HI?11*"'W(+NEXXB[G>'@[)WV"\`EX%#H(?3@`X>AX
M2_]_>/I)?2``&GDX\"E]R"X*>8):YSQXXBE]F7GG..(N"'D4,N=\>$-(?10Z
M*7UD\,I[%$(I?4```>F"\-Y[>/-*?2``_7MX4NQ_(``[>8):"#TXT(Q]F7D(
M.7CJC'T4XHA_9/!'>\@N*'F"\%I[XBXI>7C3YWQX2PE]%.*,?11*C'T@`%YY
M>#I)?4@`0>ED\&A[.-@I?8+P>WMX\BE](`"<>8):2CUXVPA]F7E*.2``^G@4
MZJI_4`!!Z63PGWL4ZBE]R"Z=>>(NC'D@`!MY>&.L?X):2CUX0OU\F7E*.3C@
MO7\48BE]%/+*?WC2O7\@`#AY%/*]?\@N/GGB+BEY>$O)?X+PG'L42KU_6``A
MZ7CC_W]X^AY]9/`*>SC`WG^"\!A[@EHI/7C#2GV9>2DY(`"Y>Q3227]@`"'I
MR"ZL>WC:WG_B+KU[>.N=?132WG^"6BD]>%+L?YEY*3D4ZMY_%-II?SC(C'UD
M\"E[@O`Y>WC+*7T@`-U[R"['>^(NWGMX\_Y\>$I'?2``_'LXZ.=\9/"H>X+P
MO7MXZPA]>.*,?7A"/7T4VHQ](``[>7``(>D@`%IY:`!!Z13RC'UXTN=\(`"8
M>8):*3V"6DH]F7DI.9EY2CD4TDE_>``AZ13BBG_(+HIYXBZ,>7AC3'T4XN=\
M%&+G?#C`O7]D\!][@EHI/8+P&'L@`/EX>,/_?\@N_GAXVKU_F7DI.>(NYW@4
MVFE_@``AZ7@[QW\4TKU_>/H>?2``''D4.KU_.,C>?R``IWO(+JQ[>.+>?^(N
MO7MXZYU]%-K>?V3P*GN"6BD]@O`Y>Q3JWG]XRTI]F7DI.2``V'MX4NQ_%.*)
M?\@NR7OB+MY[(`#Z>WCS/GTX.(Q]9/#I>(+PYWAX.RE]>-*,?7A*1WT4XHQ]
M%/*,?3C`YWQD\`A[@O`8>WC#"'T@`)EY(`!;><@NG7F(`$'IXBZ,>2``/'EX
M8ZQ_>$(]?9``(>F"6DH]>-KG?)EY2CDXR+U_@EHI/1322G^9>2DY%-+G?!3:
M:7^8`"'I%&+G?"``['C(+OYX>.*]?^(NYWAX.\=_%-J]?X):*3T4.KU_9/`_
M>YEY*3F"\#E[(`"X>WC+_W\4XHE_R"ZI>^(NO7MX^AY]>.L]?:``(>D@`!IY
M.&#>?V3PBGF"\(QY>&-*?7C2WG]X4NQ_%.+>?X):*3T4ZMY_(`#[>SC`C'V9
M>2DY9/`'>X+P&'L@`-E[>,/G?!3227]XVHQ]R"[)>^(NWGL@`%QY>/,^?132
MC'UX.DE]J`!!Z13RC'TXR"E]9/`_>X+P.7L@`)UY>,O_?\@NB'GB+HQY(`#Z
M>'AC#'V"6DH]>/KH?+``X>B9>4HY%-IJ?WCB*7T4VBE]..@(?8):YSP48BE]
MF7GG."``*GD4XH=_>-((?<@N)WGB+BEY>$OI?!3B"'VX`.'H%$H(?63PJ7N"
M\+U[(`#^>WCK*7UD\%UY>$K_?R``.7DX4/]_@O!*>7A3O7^"6N<\>.HJ?<``
M(>F9>><X(``<>1321W]X\O]_XBX'>2@H"'D4TO]_>#L(?8):*3T40A]]..!*
M?9EY*3GB+@=Y%/+)?WC*2GTH*`EY%/)*?7@[*7UD\)M[%$I*?<@`(>F"\)Q[
M>.-[?R@H7WEXVKQ_B/`>>=IN*3UX0IQ_H>LI.:+P"'D4RBE_XBY)>7A+_W_0
M`"'I>$/(?^``P>MX0F=_(`"<>Q3*G'\@`+U[VFXI/7A2YWRAZRDY%/J<?Q3J
M*7T@`.=X%#HI?2@HG7OB+H=[(`![>W@[O7_8`.'HVF[>/Q3JJ7^(\$EYHO!*
M>>(NOWMX4RI]VF[G/'A2"7VAZ^<X>.(I?13:YWP@`"EY(``(>11*YWPH**E[
M>/LI?8CPGWNB\)Q[%$KG?'CC_'^AZ]X[\`#AZWCB27T40MY_>.HI?2@HZ'@@
M`"EY(`!*>11*WG_B+NEX>$L(?8CPJ7NB\+U[%$+>?WCK/7WH`"'IXB[(>XCP
M^WC:;O\_H>O_.]IN*3VAZRDY%%(I?7CJBG]X.DI]HO#G>"``2GEX.WM_%%(I
M?2@HRGMX0TI](`"<>Q12*7UXVJI_>/)*?13B_W\@`$IYXBXH>112_W\H*"IY
M>$-*?8CPR'L44O]_^`!!Z:+PWGMX\QY](`"]>WCR:'_B+N=[VFY*/7A*"'VA
MZTHY(``(>13J2GV(\#QY%$)*?2@HZ'MX.PA]``'AZ*+P*7EX2YQ_(`![>WCB
MR7\40DI]VF[G/'CZ*7VAZ^<X(``I>13:YWSB+DAY%$KG?"@H27EX0RE]"`$!
MZ8CP^WNB\/][%$KG?'C[>W\@`-Y[>-J)?]IN"#UX4BE]H>L(.13R"'T@`"EY
MXB[_>!1*"'TH*.EXB/!=>7C[*7VB\$IY%$H(?1`!(>EX4[U_>.IJ?R``G'MX
M.DI]XBX?>=IN*3T@`$IYH>LI.2``>WL4XBE]B/#\>!12*7TH*`IY>/M*?1@!
MX>NB\.=X>#N<?Q12*7UXXJI_XBXG>=IN_S]X0DI]H>O_.R``2GD4VO]_B/`>
M>112_W\H*"IY>#M*?:+P"'D44O]_(`%!Z7A#WG]X\HA_(`"]>WA*"'WB+N=[
MVFY*/2``"'FAZTHY(`"<>Q3J2GV(\#UY%$)*?2@HZ'MX.PA]*`'AZ*+P*7EX
M2[U_%$)*?7CJR7_B+DAYVF[G/'CZ*7VAZ^<X(``I>13BYWR(\/Q[%$KG?"@H
M27EX0RE],`$!Z:+P_WMX^YQ_%$KG?'CBJ7\@`-Y[VFX(/7A2*7VAZP@Y(``I
M>13R"'WB+O]X%$H(?2@HZ7AX^RE]B/!>>11*"'TX`2'IHO!*>7A3WG\@`+U[
M>/**?^(N'WG:;BD]>#I*?:'K*3D@`$IY%.HI?8CP_7@44BE]*"@*>7C[2GU`
M`>'KHO#G>'@[O7\44BE]>.K*?R``G'O:;O\_>$)*?:'K_SL@`$IY%.+_?^(N
M)WD44O]_*"@J>7@[2GV(\!QY%%+_?T@!0>FB\`AY>$.<?R``WGMXXJA_B/`[
M>=IN2CUX2@A]H>M*.2``"'D4\DI]*"C^>Q1"2GWB+NA[>$/>?Z+P*7D4\LI_
M4`%!Z7A+>W\@`+U[B/#H>^(NR7O:;NH\>-J*?WCZ2GVAZ^<X%.KG?"``2GD4
M4N=\6`%!Z:+P_WMX^Q]]*"C=>WA+O7]X^FE_VFX*/2``G'MX\BE]H>L(.13J
MIW\4X@A](``I>>(NJGL42@A]R"ZI>WA3*7VB\,I[%$H(?8CPR7MX4SY]8`%!
MZ2``>WL@`!IYHO"G>R``W'O:;BH]>/+J?WCJ2GVAZRDY%-HI?2``2GD44BE]
MR"X*>>(N"'D@`/][>$-(?8CPJGMX.T=]%$(I?2``^WAX.\A_.-C*?SC0"'UH
M`<'K>%,(?1N/0#W<O$IA9/!=>R``2GF"\%I[%/+*?WC3O7\4^OY_(``Y>13Z
M"'UXZ^=\R"X_>>(N*7EX2^E_.,CG?#C8OW\42BA]>/OG?'`!X>L@`"AY9/`L
M>X+P.7MXRXQ](`"Z>Q3ZZG]X8[Y_%.*??\@N/WGB+BEY%.+G?'A+Z7\@`)QY
M%$KG?'@!(>DXX+U_.$#>?R``^'AXZ]Y_%$HJ?13::7_(+NEXXB[G>!3:WG]X
M.R=]%#K^?&3P'GF"\`AY(`#Y>'A#WG^``0'I>/.)?3C@S'\XP"E](`#;>Q1"
M"GUX8RE]%-)(?\@NZ'CB+N=X%-(I?7@[!WUD\`A[@O`8>Q0Z*7UXPPA](``Z
M>2``'7EX0]]_..C'?SC(_W]X._]_B`'AZ&3P3'L4.NI\%.*'?\@N)WGB+BEY
M%.+_?WA+Z7P42C]]9/`_>X+P.7L@`#AY>,O_?WC[!WTXZ.A_.-#G?(+P6GMX
M0^=\D`$!Z7C3C'UX8_Y_(`#\>SC`WG\40@I]%-IH?\@N*'GB+BEY%-KG?'A+
M"7T@`)MYH`$!Z11*YWPXV.E_>$O>?Y@!(>D@`/EX%$(*?13BB'\42BI]%.JI
M?\@NZ7CB+N=X%.K>?W@[)WT4.OY\9/`>>X+P&'L@`/IX>,/>?\@NZ'AX\XE]
MXB[G>#C8S']X.P=].,@I?63P*'N"\#E[>&,I?7C+"'T4XBE]>$/??R``''D4
M.BE].-#_?SC@QW\@`#AY>#O_?Z@!X>@@`-U[9/`,>Q0ZZGP4VF=_R"XG>>(N
M*7D4VO]_>$OI?!1*/WUD\%][@O!:>R``.7EXT_]_>/L'?3C@Z'\XP.=\@O`8
M>WA#YWRP`0'I>,.,?7AC_G\@`/M[.,C>?Q1""GT4ZJA_R"XH>>(N*7D4ZN=\
M>$L)?2``G7G``0'I%$KG?#CHZ7]X2]Y_N`$AZ2``^G@40@I]%-IH?Q1**GT4
MXHE_R"[I>.(NYW@4XMY_>#LG?10Z_GQD\#Y[@O`Y>R``^'AXR]Y_R"[H>'CS
MB7WB+N=X..C,?W@[!WTXT"E]9/!(>X+P6GMX8RE]>-,(?13:*7UX0]]_(``;
M>10Z*7TXP/]_.-C'?R``.7EX._]_R`'AZ"``W'MD\"Q[%#KJ?!3JIW_(+B=Y
MXBXI>13J_W]X2^E\%$H_?63P'WN"\!A[(``Z>7C#_W]X^P=].-CH?SC(YWR"
M\#E[>$/G?-`!`>EXRXQ]>&/^?R``_7LXT-Y_%$(*?13BB'_(+BAYXBXI>13B
MYWQX2PE](`"<>>`!`>D42N=\..#I?WA+WG_8`2'I(`#X>!1""GT4ZJA_%$HJ
M?13::7_(+NEXXB[G>!3:WG]X.R=]%#K^?&3P7GN"\%I[(`#Y>'C3WG_(+NAX
M>/.)?3C@S'\XP"E]XB[G>'AC*7UX.P=]%.HI?63P"'L4.BE]@O`8>^@!X>AX
MPPA]9/`]>WA#WW\@`"QY%#KJ?#C(_W^"\#E[%.*'?WC+N7_(+B=YXBXI>2``
M&WEX2^E\>,L'?3A@YWPXV"A_(`#:>WA#YWSP`0'I.-C>?WCS_W\4XO]_%$(*
M?11*/WT4TDA_(``^><@N*'GB+BEY%-+G?'A+"7UD\)]Y%$KG?/@!(>F"\(QY
M>&/_?R``^GAX^SU_(`#L>Q1**GTX\+U_%-II?^(NZ7@H*.=X.&`H?WA+YWQD
M\,E[@O#>>WA#O7]X\RE]%-J]?WA+_W\X8"A].-#_?Q0ZO7]X0_]_``(!Z>(N
MIWL@`#Q[(``[>11"2GTH**A[>#L(?13B2GUD\$=[@O!:>WC3^GP44E]]"`+A
MZ!1"2GUXTBA]8LH@/7CJ"'W6P2EAXBY?>2``*7D@``AY%#KI?!1BAWTH*$=Y
M>/OG?!1B"'T4.@A]HO"_>XCPIWOB+AUY>/O_?!`"X>AX^EY_(`!:>WA2WG\4
M.NE\(`#>>Q3:9W\H*`=Y>.OG?!3:WG\4.MY_B/!'>:+P2GGB+MQ[>%/J?!@"
MX>AX4OU_(`#_>WA"O7\4.NE\(`"]>Q32YWP4ZN=\*"C=>WCCO7\4ZN=\B/`=
M>:+P"'GB+OQX>$.H?R`"H>N(\/MX%.JI?Q3ZO7]X0E]]>/+_?R``2GD@`/][
M%/J]?R@H_WAXX_]_%/J]?XCPWWNB\-Y[XBZ\>WCS_G\H`N'K%/KI?Q12_W]X
M\@I]>#I*?:+PYW@@`$IY>#M[?Q12_W\H**I[>.-*?2``"'D44O]_,`)!Z8CP
MO'OB+N=[%%))?11"2GUXVLA_>.H(?:+PO7L@``AY>.N<?Q1"2GTH*.A[>#L(
M?7CB9W\40DI].`(!Z2``WGMX^N=\(`![>R``YW@40@E]%/((?>(N7GD4.@A]
M*"A'>7CSYWR(\/Y[%#H(?:+P_WM``N'H>/O??^(N'7EX^IY_(`"<>Q0ZZ7QX
M4MY_%-KG?"``WGL4\N=\*"@>>7CKWG^(\%MY2`*AZZ+P2GD4\N=\>%-[?^(N
M_GAXVNI_%.JI?WA"2GT4XKU_(`!*>8CP''D44KU_*"CJ>'CS2GVB\`AY4`+!
MZWA#G'\44KU_>.)J?R``_WL4\LE_>#I*?13ZWG\@`$IYXBZH>Q12WG\H**I[
MB/#_>'A#2GVB\.=X%%+>?U@"0>EX.^=_>#J(?R``>WMXZ@A]XB[?>Q1227T@
M``AY%-I*?8CPNWL40DI]*"C(>WC["'VB\+U[%$)*?6`"`>EXZWM_>-K_?"``
MG'MX\O]_XBY=>11""7T@`/][%.((?8CPW'L4^@A]*"A?>7CK_W^B\-Y[<`*A
MZQ3Z"'UH`N'K>/.<?R``YWCB+AYY%.JI?Q3ZZ7\4.O]_>.)G?WA2YWP@`'M[
M(`#G>!3:O7\4.O]_*"@'>7CSYWR(\!MY%#K_?XCP1WFB\$IYXB[^>WA3ZGQX
M4H=_(`"<>WA"YWRB\`AY(`#G>'A#>W\4.KU_*"CG>WCSYWQX`L'K>-I(?7CZ
M"'T4.KU_(``(>>(NIWL4\LE_(`!*>13BWG^(\/Q[%$+>?R@HJ'MX.PA]@`+A
MZ*+P_WMX^YQ_%$+>?^(NR'L4.NE\%%+G?'CB:G]XZDI](`![>R``2GD44N=\
M*"C*>WA#2GV(`@'I%%+G?(CPJGNB\+U[XB[_>'CK77T40@E]>.J*?Q3:"'UX
M\DI](`"<>R``2GD44@A]*"CJ>'C[2GV0`N'K%%((?8CPRGNB\-Y[>/->?13Z
MZ7]X\JI_%.+_?W@Z2GWB+AQY(`!*>2``O7L44O]_*"@*>7CC2GT44O]_B/#J
M>*+PYWCB+OQ[>#M'?9@"0>D46F=](`!K>11227T4ZDI]>#K=?R``8_EX0KU_
M(`#>>R``O7L4ZDI]R"[]>WCCO7\4ZDI]B/`=>:+P"'EX0ZA_H`*AZQ3J*7T4
M`BE]>$+@?'CZ`'P4\BE](```>.(N7GD4`BE]R"Y`>7CS`'P4(DI]%`(I?2``
M2GD@`"EY%"H(?0@`0_FB\.I[(``(>0``(_F(\.E[>%,I?1@``_D4,LE\(`#&
M>!``P_BH`B'I\(]-Z7E2*7T``$`Y#`""06W%_TL8`$'H\`(A.%0$`$@`````
M`````8`(```"`$P\,"E".*8""'R``&`X$``!^.'_(?@9RO]+&`!!Z$5G0#T@
M`"$X`2-*80``0_G-[T`]B:M*82``2GD(`$/YNIA`/?[<2F$@`$IY$`!#^3(0
M0#UV5$IA&`!#^=+#0#WPX4IA(`!*>2``0_D``$`Y>`!#D2@`0_DP`$/Y$``!
MZ*8#"'P@`(!.``````````&``````@!,/)PH0CBF`@A\)!^I>'$#`$BQ_R'X
M>!M^?'@CGWQX*[U\*`!#Z112*7T@`"EY0$@J?!``@4`P`$/I`0!*.3``0_EZ
M`'[H,`!>Z2@`/OE"'ZE[.`">.P``(RP42BI],``^^5@`@D%``",A>.N[?P!(
M'7P(`(%`>$L[?;0'>G]X^^1_>--%?Q0:?'QQR?]+&`!!Z'@`/H$4VBE]0``)
M+'@`/I$X`()`4.B[?Q32_W^T![U_>//#?S7I_TL_`!TL)`"!07CKI7]X^^1_
M>..#?RW)_TL8`$'H>`"^DU``(3C8`@!(``#_Z`@`'^D0`%_I&``_Z<#_O3M`
M`/\[M`>]?P``_/@(`!SY$`!<^1@`//G@___HZ/\?Z?#_7^GX_S_I(`#\^"@`
M'/DP`%SY.``\^83__TL``````````8`&```"`$P\7"=".*8""'PH`"0Y@/]`
M.3$"`$BQ_R'X.`"D.W@;?GQX(Y]\+$R`?S``)#DL3&!_*``DZ;[N)56B[BEY
M`0"E.#@`!2RT!Z-\KDE=?10:?7PT`8%`0`"E(```@#BT!Z5\F<7_2Q@`0>AX
M^^-_/>C_2S@`H#@``(`X>.NC?WW%_TL8`$'H<`!_DW0`GY-X^^-_&>C_2P``
M/^EX^^-_`D8I>0``/ID``#_I`H0I>0$`/ID``#_I`L(I>0(`/ID``#_I`P`^
MF0@`/^D"1BEY!``^F0@`/^D"A"EY!0`^F0@`/^D"PBEY!@`^F0@`/^D'`#Z9
M$``_Z0)&*7D(`#Z9$``_Z0*$*7D)`#Z9$``_Z0+"*7D*`#Z9$``_Z0L`/ID8
M`#_I`D8I>0P`/ID8`#_I`H0I>0T`/ID8`#_I`L(I>0X`/ID8`#_I#P`^F2``
M/^D"1BEY$``^F2``/^D"A"EY$0`^F2``/^D"PBEY$@`^F2``/^D3`#Z9I</_
M2Q@`0>A0`"$X^```2#@`I2```(`XM`>E?.S^_TL``````````8`%``````!@
M````8````&````!@````8````&`"`$P\H"5"./__@CTH?(SI^/_A^___XC_1
M_R'X,'S_.___+"P\`()!I@((?!@`0?CX__\[0``!^````&```$)@I@.)?2$$
M@$X8`$'H^?^?Z?__+"SL_X)`0``!Z*8#"'PP`"$X^/_AZR``@$Z@_X'ZJ/^A
M^K#_P?JX_^'ZP/\!^\C_(?O0_T'[V/]A^^#_@?OH_Z'[\/_!^_C_X?L0``'X
M(`"`3J#_@>JH_Z'JL/_!ZKC_X>K`_P'KR/\AZ]#_0>O8_V'KX/^!ZQ```>CH
M_Z'KI@,(?/#_P>OX_^'K(`"`3O#_P>L0``'H^/_AZZ8#"'P@`(!.````8*"B
M`0``````I@((?`4`GT*F`FA]&`!!^/#_2^BF`PA\4&"+?11:8GW0_PPX``"+
MZ8+P`'BF`XE]"`!KZ2`$@$[(__]+Q/__2\#__TN\__]+N/__2[3__TNP__]+
MK/__2ZC__TND__]+H/__2YS__TN8__]+E/__2Y#__TN,__]+B/__2X3__TN`
M__]+?/__2WC__TMT__]+</__2VS__TMH__]+9/__2V#__TM<__]+6/__2U3_
M_TM0__]+3/__2TC__TM$__]+0/__2SS__TLX__]+-/__2S#__TLL__]+*/__
M2R3__TL@__]+'/__2QC__TL4__]+$/__2PS__TL(__]+!/__2P#__TO\_O]+
M^/[_2_3^_TOP_O]+[/[_2^C^_TOD_O]+X/[_2]S^_TO8_O]+`@!,/'0C0CBF
M`@A\$``!^.'_(?C)R/]+````8"``(3@0``'HI@,(?"``@$XO=&UP`%!!4E]4
M35!$25(`5$5-4$1)4@!435``55-%4@!54T523D%-10`N+@`E<R\E<P!$>6YA
M3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`
M97AE`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$52
M3#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$
M`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!
M4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?
M4$%42`!365-414T`)3`R>`!P87(M`"5S)7,E<R5S`"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`
M)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E
M(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@!P87)L`"YP
M87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE
M=25S`$%21U8`&`!P97)L`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#4P`%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H`+64`+2T`979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D
M>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L
M;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)'!A<E]T96UP
M+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,
M14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I
M;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E
M<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M
M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@
M;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-
M4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@
M,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@
M+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D
M<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD
M>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H
M;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE
M;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T
M96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@
M=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@
M?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F
M26YT97)N86QS.CI005(Z.D)/3U0["B1005)?34%'24,@/2`B7&Y005(N<&U<
M;B(["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D
M7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H
M)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I
M+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@
M.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*
M;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L
M87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R
M;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&UA9VEC
M7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE*2!["B1M86=I8U]P;W,@
M/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E("1C:'5N:U]S:7IE*2`^
M(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T["GT@96QS92!["B1M86=I
M8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]"G=H:6QE("@D;6%G:6-?
M<&]S(#X](#`I('L*<V5E:RA?1D@L("1M86=I8U]P;W,L(#`I.PIR96%D*%]&
M2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RDI.PII
M9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2![
M"B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D8VAU
M;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@/"`P.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*)&1A
M=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(
M+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T
M:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D
M(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F
M:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]
M?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S
M96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\
M*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN
M*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL
M92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L
M;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%
M35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E
M>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD[
M"GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE
M879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*
M8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(
M+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D
M;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U
M;&4["FUY("1I;F9O(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@
M;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO
M9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&
M:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O
M<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1I;F9O+3Y[8G5F
M?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D
M9FEL96YA;64@/2!?=&5M<&9I;&4H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O
M+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@
M(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T
M=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@
M9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M
M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D
M24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF
M("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M
M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@
M+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES
M='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP
M,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@
M("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@
M)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!
M4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U
M<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)5
M1WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P
M=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L
M:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS
M("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D
M05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%2
M7T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@
M<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@
M>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L
M87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H
M)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H
M)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2![
M"B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N
M9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q
M.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R
M(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H
M)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I
M.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[
M)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D
M:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R
M<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M
M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@
M<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]
M?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I
M92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@
M82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#
M<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U
M="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I
M('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I
M;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A
M7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C
M86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D
M97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@
M>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D
M=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!
M4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H
M)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M
M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E
M="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*
M:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D
M=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH
M)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[
M87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB
M97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$
M>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY
M("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I
M='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L
M("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]
M("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA
M<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO
M;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("10
M05(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@
M/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L*
M*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]
M"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD
M;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN
M7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL
M(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD*
M*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@
M)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@
M;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D[
M"B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B
M*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP
M;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^
M87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I
M='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN
M="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-2
M0S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*
M?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H
M95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C
M:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY
M("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F:"P@(CPB
M+"`D;W5T*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L
M;W-E*"1F:"D["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C
M86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I
M.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N
M86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H
M*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F:"T^8VQO
M<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D
M969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!0
M05(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E
M($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]
M($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C
M($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^
M9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@
M(B0A.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R
M-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I
M*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@
M<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M
M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY
M("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S
M<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#
M;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?
M(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K
M:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S
M(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I
M;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M
M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@
M*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE
M<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;
M("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M
M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E
M871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S
M96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I
M;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I
M<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97([
M"G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R
M;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E
M(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L
M('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A
M;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R
M8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA
M<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E
M<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!]
M.PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E
M;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%
M3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-
M4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D
M969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U
M<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED
M*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO
M9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]
M"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60[
M"GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[
M55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM
M>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C
M:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@
M*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G
M;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS
M965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@
M*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E
M860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY
M("1D:6=E<W0@/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T
M>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96XH;7D@)&9H+"`B/"(L("1P
M<F]G;F%M92D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC
M;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E<W0["GT@?'P@)&UT:6UE.PHD<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M)&1I9V5S="(["GT*8VQO
M<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]
M"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D;F%M
M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P
M87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T
M96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D
M=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A(CL*
M8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*
M8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA
M;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I
M.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!2
M3T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N
M86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O
M9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E
M;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@[
M"GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA
M;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D
M9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(
M?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E
M<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]
M7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE
M(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F
M:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/
M1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z
M.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R
M.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]
M?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG
M>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*
M<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$
M?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!
M3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"
M54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1?
M?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%
M3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI
M<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`]
M(")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6
M>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF
M("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E
M(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*
M)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%.
M/2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@
M*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN
M="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*
M<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[
M)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I
M=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K
M86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF
M:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP
M;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C
M:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID
M;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]
M("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ
M7U]%4E)/4CL*,3L*7U]%3D1?7PH```!P97)L>'-I+F,`7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("````$;`SO8````&@```)R'__^0!```P(S_
M_P@!``"0C?__0`$``/"-__]@`0``E([__X@!```8D/__Q`$``,"0___L`0``
MV)+__R@"```\D___2`(``+23__]L`@``C)3__Y@"``"DE/__K`(``+26___\
M`@``Z);__Q`#``!,F/__.`,```R:__]H`P``F)K__X@#``#DFO__J`,``*B;
M___<`P``Q*+__R`$``"LIO__7`0``$2G__^X!```S+S___@$``!@O?__&`4`
M`*"^__]0!0``7,'___`````0``````````%Z4@`$>$$!&PP!`!0````8````
M9,#__RP!````00E!`$<&030````P````L(O__]``````0PE!`$&:!IL%G`2=
M`YX"GP$107Y"#E!+"@X`0M_>W=S;V@9!"P``'````&@```!(C/__8`````!%
M#G`107Y-#@!"!D$````D````B````(B,__^D`````$4)00">`I\!0PZ``1%!
M?ET.`$'?W@9!.````+`````$C?__A`$```!#"4$`09@(F0>:!IL%G`2=`YX"
MGP$107Y!#L`"`E@.`$'?WMW<V]K9V`9!)````.P```!,CO__J`````!$"4$`
MGP%##M`!$4%^7PX`0=\&00```#@````4`0``S([__Q@"````0PE!`$&9!YH&
MFP6<!)T#G@*?`1%!?D$.L`$"?0X`0=_>W=S;VMD&00```!P```!0`0``J)#_
M_V0`````1PX@$4%^3`X`0@9!````(````'`!``#LD/__>`````!$"4$`GP%$
M#C`107Y2#@!!WP9!*````)0!``!`D?__V`````!#"4$`09T#G@*?`1%!?D$.
MH$%L#@!"W][=!D$0````P`$``.R1__\8`````````$P```#4`0``\)'__Q`"
M````10E!`!%(?T&4#)4+E@J7"9@(F0>:!IL%G`2=`YX"GP$107Y!#N`B`G8.
M`$3?WMW<V]K9V-?6U=0&009(````$````"0"``"PD___-``````````D````
M.`(``-"3__]D`0```$0)00"?`4,.,!%!?@).#@!!WP9!````+````&`"```,
ME?__P`$```!%"4$`09P$G0.>`I\!$4%^00ZP`0)E#@!!W][=W`9!'````)`"
M``"<EO__C`````!+#F`107Y,#@!$!D$````<````L`(```B7__],`````$4.
M(!%!?D@.`$(&00```#````#0`@``-)?__\0`````0PE!`$&<!)T#G@*?`1%!
M?D$.@`%."@X`0=_>W=P&00L```!`````!`,``,27__\<!P```$4)00!!EPF8
M")D'F@:;!9P$G0.>`I\!$4%^1P[P@P(#M0$.`$+?WMW<V]K9V-<&00```#@`
M``!(`P``G)[__^@#````0PE!`$&8")D'F@:;!9P$G0.>`I\!$4%^00Z@`0+Q
M#@!!W][=W-O:V=@&03````"$`P``2*+__Y@`````10E!`)X"GP%##G`107Y3
M"@X`109!W]Y!"T$.`$'?W@9!```D````N`,```2#__]D`@```$<.D`$107Z>
M`I\!`H8*#@!"W]X&00L`/````.`#``"$HO__B!4```!$"4$`09@(F0>:!IL%
MG`2=`YX"GP$107Y!#O`%`U@%#@!!W][=W-O:V=@&00```!P````@!```S+?_
M_Y0`````1@X@$4%^1`X`5P9!````-````$`$``!`N/__0`$```!$"4$`09H&
MFP6<!)T#G@*?`1%!?D$.4'(*#@!!W][=W-O:!D$+```P````>`0``$BY__^D
M`0```$4)00!!FP6<!)T#G@*?`1%!?D$.4`):"@X`0=_>W=S;!D$+````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````__________\`
M`````````/__________```````````!``````````T#`````````0``````
M```8`P````````\`````````1`0````````,`````````+@8````````#0``
M``````",6P```````/7^_V\`````(`(````````%`````````'`,````````
M!@````````#X`@````````H`````````8@0````````+`````````!@`````
M````%0````````````````````,`````````"/T!```````"`````````+@%
M````````%``````````'`````````!<``````````!,```````````!P````
M`'A:`````````P``<`````````````````<`````````V!`````````(````
M`````"@"````````"0`````````8`````````!@```````````````````#[
M__]O``````$```@`````^?__;P`````+````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'\"````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````@``````_____P````"X6P```````.-;````
M``````````````"]6P```````+U<````````R%L```````#/7````````-!;
M``````````````````#46P```````-E;``````````````````!Q7@``````
M`$=#0SH@*$%L<&EN92`Q,"XR+C`I(#$P+C(N,```+G-H<W1R=&%B`"YI;G1E
M<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L82YD>6X`+G)E;&$N
M<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N
M96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N9'EN86UI8P`N9V]T`"YD871A`"YB
M<W,`+F-O;6UE;G0`````````````````````````````````````````````
M```````````````````````````````````````````+`````0````(`````
M``````(``````````@```````!X````````````````````!````````````
M````````$P```/;__V\"`````````"`"````````(`(```````#8````````
M``,`````````"````````````````````!T````+`````@````````#X`@``
M`````/@"````````>`D````````$`````P````@`````````&``````````E
M`````P````(`````````<`P```````!P#````````&($````````````````
M```!````````````````````+0````0````"`````````-@0````````V!``
M```````H`@````````,`````````"``````````8`````````#<````$````
M0@``````````$P`````````3````````N`4````````#````$`````@`````
M````&`````````!!`````0````8`````````N!@```````"X&````````#0`
M```````````````````$````````````````````1P````$````&````````
M```9`````````!D```````",0@``````````````````(```````````````
M`````$T````!````!@````````",6P```````(Q;````````+```````````
M``````````0```````````````````!3`````0````(`````````N%L`````
M``"X6P```````$P]```````````````````(````````````````````6P``
M``$````"``````````29````````!)D```````#<````````````````````
M!````````````````````&D````!`````@````````#@F0```````."9````
M````K`0```````````````````0```````````````````!S`````0````,`
M````````*/L!```````H^P```````!`````````````````````(````````
M````````````>@````$````#`````````#C[`0``````./L````````0````
M````````````````"````````````````````($````&`````P````````!(
M^P$``````$C[````````P`$````````$``````````@`````````$```````
M```\````"`````,`````````"/T!```````(_0```````/@!````````````
M```````(``````````@`````````B@````$````#``````````#_`0``````
M`/\```````!H``````````````````````$````````(`````````(\````!
M`````P````````````(``````````0``````>`````````````````````@`
M``````````````````"5````"`````,`````````>``"``````!X``$`````
M`&@0```````````````````(````````````````````F@````$````P````
M````````````````>``!```````<`````````````````````0`````````!
M``````````$````#`````````````````````````)0``0``````HP``````
:``````````````$`````````````````````
